@@ -1,15 +1,21 @@
 
+import dataclasses
 import logging
 import os
 import shlex
-from pathlib import Path
 import subprocess as sp
+import typing as t
+from pathlib import Path
 
 from slap.application import Application, Command, option
+from slap.configuration import Configuration
 from slap.plugins import ApplicationPlugin
 from slap.project import Project
 from slap.util.python import Environment
 
+from databind.core.settings import Alias, ExtraKeys
+
+
 logger = logging.getLogger(__name__)
 venv_check_option = option(
   "--no-venv-check",
@@ -27,6 +33,22 @@ def venv_check(cmd: Command, message='refusing to install') -> bool:
   return True
 
 
+@dataclasses.dataclass
+@ExtraKeys(True)
+class InstallConfig:
+  """ Separate install configuration under Slap that is entirely separate from the build system that is being used.
+  This configures the behaviour of the `slap install` command. """
+
+  #: Additional extras that are installable with `--extras` or `--only-extras`. These are taken into account
+  #: for projects as well as the monorepository root. They may contain semantic version selector (same style
+  #: as supported by Poetry).
+  extras: dict[str, list[str]] = dataclasses.field(default_factory=dict)
+
+  #: A list of extra names to install in addition to `dev` when using `slap install` (unless `--no-dev` is
+  #: specified). If this option is not set, _all_ extras are installed.
+  dev_extras: t.Annotated[list[str] | None, Alias('dev-extras')] = None
+
+
 class InstallCommandPlugin(Command, ApplicationPlugin):
   """ Install your project and its dependencies via Pip. """
 
@@ -71,6 +93,10 @@ class InstallCommandPlugin(Command, ApplicationPlugin):
   ]
 
   def load_configuration(self, app: Application) -> None:
+    from databind.json import load
+    self.config: dict[Configuration, InstallConfig] = {}
+    for obj in app.configurations():
+      self.config[obj] = load(obj.raw_config().get('install', {}), InstallConfig, filename=str(obj))
     return None
 
   def activate(self, app: Application, config: None) -> None:
@@ -78,6 +104,8 @@ class InstallCommandPlugin(Command, ApplicationPlugin):
     app.cleo.add(self)
 
   def handle(self) -> int:
+    from slap.ext.project_handlers.poetry import convert_poetry_dependencies
+
     for a, b in [("only-extras", "extras"), ("no-root", "link"), ("only-extras", "link")]:
       if self.option(a) and self.option(b):
         self.line_error(f'error: conflicting options <opt>--{a}</opt> and <opt>--{b}</opt>', 'error')
@@ -101,6 +129,9 @@ class InstallCommandPlugin(Command, ApplicationPlugin):
     extras = {x.strip() for x in (self.option("extras") or self.option("only-extras") or '').split(',') if x.strip()}
     found_extras = {'dev'}
 
+    if not self.option("no-dev") and self.app.repository in self.config:
+      extras.update(self.config[self.app.repository].dev_extras or [])
+
     dependencies = []
     for project in projects + project_dependencies:
       if not project.is_python_project: continue
@@ -111,14 +142,31 @@ class InstallCommandPlugin(Command, ApplicationPlugin):
     for project in projects:
       if (not self.option("no-dev") and not self.option("only-extras")) or 'dev' in extras:
         dependencies += project.dependencies().dev
-      for extra in extras - {'dev'}:
-        project_extras = project.dependencies().extra.get(extra)
-        if project_extras is not None:
+
+      # Determine the extras to install.
+      config = self.config[project]
+      project_extras = set(extras)
+      if not self.option("no-dev"):
+        if config.dev_extras is None:
+          project_extras.update(project.dependencies().extra.keys())
+          project_extras.update(config.extras.keys())
+        else:
+          project_extras.update(config.dev_extras)
+
+      for extra in project_extras - {'dev'}:
+        extra_deps = project.dependencies().extra.get(extra)
+        if extra_deps is not None:
           found_extras.add(extra)
-          dependencies += project_extras
+          dependencies += extra_deps
+
+    # Look for extras also in the Slap specific install configuration.
+    for obj, config in self.config.items():
+      for extra in extras:
+        dependencies += convert_poetry_dependencies(config.extras.get(extra, []))
+        found_extras.add(extra)
 
     if missing_extras := extras - found_extras:
-      self.line_error(f'error: the follow extras do not exist: <fg=yellow>{missing_extras}</fg>', 'error')
+      self.line_error(f'error: extras that do not exist: <fg=yellow>{missing_extras}</fg>', 'error')
       return 1
 
     pip_command = [self.option("python"), "-m", "pip", "install"] + dependencies
